.. _correspondence:


correspondence
==============

.. raw:: html

    <br>

| **From:** Bart Thate <bthate@dds.nl>
| **To:** otp.informationdesk@icc-cpi.int
| **Subject:** Information that the king of the netherlands is aware that the
|          medicine administered with the use of new defines laws are proven
|          to be poison and is commiting 3 of 5 genocide crimes on parts of
|          the population here in the netherlands
| **Message-ID:** <e49d02a2-6a8e-ad64-6c8d-9abd45cf5c0e@dds.nl>
| **Date:** Mon, 21 Jan 2019 16:17:13 +0100


.. raw:: html

    <br>


.. _otp1:

otp1
----

.. raw:: html

    <br><br>

.. image:: OTP1.png

.. _otp2:

otp2
----

.. raw:: html

    <br><br>

.. image:: OTP2.png

